@@ -6,13 +6,13 @@ class EBCompilerTestCase(unittest.TestCase):
         input = 'a || (!b && !c)'
         output = EBCompiler.convert(input)
 
-        self.assertEqual(output, 'a IS TRUE || (b IS FALSE && c IS FALSE)')
+        self.assertEqual(output, 'a IS TRUE OR (b IS FALSE AND c IS FALSE)')
 
     def test_large(self):
         input = '(a! && b!? && !?c && d!? && e!? && !?f && g!?) || (a && b? && c? && e? && f? && ?g)'
         output = EBCompiler.convert(input)
 
-        self.assertEqual(output, '(a IS FALSE && b IS NULL && c IS NULL && d IS NULL && e IS NULL && f IS NULL && g IS NULL) || (a IS TRUE && b IS NOT NULL && c IS NOT NULL && e IS NOT NULL && f IS NOT NULL && g IS NOT NULL)')
+        self.assertEqual(output, '(a IS FALSE AND b IS NULL AND c IS NULL AND d IS NULL AND e IS NULL AND f IS NULL AND g IS NULL) OR (a IS TRUE AND b IS NOT NULL AND c IS NOT NULL AND e IS NOT NULL AND f IS NOT NULL AND g IS NOT NULL)')
 
     def test_syntax_error(self):
         input = '!a < b'
